import OHeader from '@/components/o-header'
import OSearch from '@/components/o-search'
import { Cell, Icon, Popover, Image, Checkbox, CheckboxGroup, Button } from 'vant'
import { defineComponent, reactive } from 'vue'
import styles from './student-list.module.less'
import checkboxCheck from '@/common/images/icon-checkbox-check.png'
import checkboxDefault from '@/common/images/icon-checkbox-default.png'
import OSticky from '@/components/o-sticky'

export default defineComponent({
  name: 'student-list',
  emits: ['close'],
  setup(props, { slots, attrs, emit }) {
    const state = reactive({
      showPopover: false,
      actions: [
        { text: '全部乐团', color: 'var(--van-primary-color)' },
        { text: '交付团' },
        { text: '晋升团' }
      ],
      oPopover: false,
      check: [],
      checkboxRefs: [] as any
    })

    const onSelect = (type: string) => {
      console.log(type, 'tye')
      console.log(state.checkboxRefs[type])
      state.checkboxRefs[type].toggle()
    }

    const onSubmit = () => {
      emit('close')
    }

    return () => (
      <div class={styles.studentList}>
        <OSticky position="top">
          <OHeader title="选择学生" />
          <OSearch inputBackground="white" background="#F8F8F8" />
          <div style={{ padding: '8px 13px 16px', background: '#F8F8F8' }}>
            <Popover
              v-model:show={state.showPopover}
              actions={state.actions}
              showArrow={false}
              placement="bottom-start"
              offset={[0, 12]}
              style={{ zIndex: '9999' }}
            >
              {{
                reference: () => (
                  <div class={styles.searchBand}>
                    全部乐团 <Icon name={state.showPopover ? 'arrow-up' : 'arrow-down'} />
                  </div>
                )
              }}
            </Popover>
            <Popover
              v-model:show={state.oPopover}
              actions={state.actions}
              showArrow={false}
              placement="bottom"
              offset={[0, 12]}
              style={{ zIndex: '9999' }}
            >
              {{
                reference: () => (
                  <div class={styles.searchBand} style="margin-left: 16px">
                    武汉小学2022预备团 <Icon name={state.oPopover ? 'arrow-up' : 'arrow-down'} />
                  </div>
                )
              }}
            </Popover>
          </div>
        </OSticky>

        <CheckboxGroup v-model={state.check}>
          {[1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 6].map((value: any) => (
            <Cell v-model={state.check} center onClick={() => onSelect(value)}>
              {{
                icon: () => (
                  <Image
                    class={styles.img}
                    src="https://daya.ks3-cn-beijing.ksyuncs.com/12/1670231208704.png"
                  />
                ),
                title: () => (
                  <div class={styles.content}>
                    <p class={styles.name}>长毛</p>
                    <p class={styles.class}>三年级</p>
                  </div>
                ),
                'right-icon': () => (
                  <Checkbox
                    name={value}
                    ref={(el: any) => (state.checkboxRefs[value] = el)}
                    onClick={(e: any) => {
                      e.stopPropagation()
                      e.preventDefault()
                    }}
                    v-slots={{
                      icon: (props: any) => (
                        <Icon
                          class={styles.iconChecked}
                          name={props.checked ? checkboxCheck : checkboxDefault}
                        />
                      )
                    }}
                  />
                )
              }}
            </Cell>
          ))}
        </CheckboxGroup>

        <OSticky position="bottom">
          <div class={['btnGroup', styles.btnMore]}>
            <Button type="primary" plain round>
              全选
            </Button>
            <Button type="primary" round block onClick={onSubmit}>
              确认
            </Button>
          </div>
        </OSticky>
      </div>
    )
  }
})
