import OHeader from '@/components/o-header'
import { Button, Checkbox, CheckboxGroup, Icon, Image } from 'vant'
import { defineComponent, reactive, ref } from 'vue'
import styles from './subject-list.module.less'
import checkboxCheck from '@/common/images/icon-checkbox-check.png'
import checkboxDefault from '@/common/images/icon-checkbox-default.png'
import OSticky from '@/components/o-sticky'

export default defineComponent({
  name: 'subject-list',
  emits: ['close'],
  setup(props, { slots, attrs, emit }) {
    const state = reactive({
      check: [],
      checkboxRefs: [] as any
    })

    const onSelect = (type: string) => {
      state.checkboxRefs[type].toggle()
    }

    const onSubmit = () => {
      console.log(state.check)
      emit('close')
    }

    return () => (
      <div style={{ minHeight: '100vh' }}>
        <OHeader title="选择声部" />

        <CheckboxGroup class={styles.subjectList} v-model={state.check}>
          {[1, 2, 3, 4, 5].map((value: any) => (
            <div class={styles.subject} onClick={() => onSelect(value)}>
              <Checkbox
                name={value}
                class={styles.checkbox}
                ref={(el: any) => (state.checkboxRefs[value] = el)}
                v-slots={{
                  icon: (props: any) => (
                    <Icon
                      class={styles.iconChecked}
                      name={props.checked ? checkboxCheck : checkboxDefault}
                    />
                  )
                }}
              />
              <Image
                class={styles.img}
                src="https://daya.ks3-cn-beijing.ksyuncs.com/12/1670231208704.png"
              />
              <p class={styles.name}>长笛长笛长笛长笛长笛长笛s</p>
            </div>
          ))}
        </CheckboxGroup>

        <OSticky position="bottom">
          <div class={['btnGroup', 'btnMore']} style="padding-left: 13px; padding-right: 13px;">
            <Button round color="#CCCCCC" onClick={() => emit('close')}>
              取消
            </Button>
            <Button type="primary" round onClick={onSubmit}>
              确认
            </Button>
          </div>
        </OSticky>
      </div>
    )
  }
})
